import { useEffect, useState } from "react"

const useFetch = (url, params, initialData) => {
    const [data, setData] = useState(initialData)
    const [loading, setLoading] = useState(true)
    const [error, setError] = useState("")

    useEffect(() => {
        fetch(url, params)
            .then(res => {
                if (!res.ok) {
                    switch (res.status) {
                        case 401:
                            throw new Error("Ошибка авторизации")
                        case 404:
                            throw new Error("Объект не найден")
                        default: {
                            throw new Error("Ошибка ответа от сервера")
                        }
                    }
                }

                return res.json()
            })
            .then(data => {
                setData(data)
                setLoading(false)
            })
            .catch(err => {
                setError("Ошибка сети")
                setLoading(false)

                if (import.meta.env.DEV) {
                    console.log(url, params, err)
                }
            })
    }, [url, params])

    return { data, loading, error }
}

export default useFetch
